package com.zanxiang.sdk.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.zanxiang.common.enums.HttpStatusEnum;
import com.zanxiang.mybatis.entity.UserToken;
import com.zanxiang.sdk.domain.dto.UserTokenDTO;

/**
 * @author : lingfeng
 * @time : 2022-06-08
 * @description : 用户token管理
 */
public interface UserTokenService extends IService<UserToken> {

    /**
     * 通过token设备获取token详情
     *
     * @param token      : 用户token
     * @param deviceType : 设备类型
     * @return : 返回用户token详情
     */
    UserTokenDTO getTokenInfoByTokenDevice(String token, Integer deviceType);

    /**
     * 通过用户设备获取token详情
     *
     * @param userId     : 用户id
     * @param deviceType : 设备类型
     * @return : 返回token
     */
    UserTokenDTO getTokenInfoByUserDevice(Long userId, Integer deviceType);

    /**
     * 用户token校验
     *
     * @param token      : 用户token
     * @param userId     : 用户id
     * @param deviceType : 设备类型
     * @return : 返回token校验结果
     */
    HttpStatusEnum checkUserToken(String token, Long userId, Integer deviceType);

    /**
     * 获取用户token
     *
     * @param userId     : 用户id
     * @param deviceType : 设备类型
     * @return : 返回token
     */
    String getUserToken(Long userId, Integer deviceType);

    /**
     * 删除用户token
     *
     * @param userId : 用户id
     */
    void deleteUserToken(Long userId);
}
